#include <cassert>
#include <cmath>
#include <cstdio>
#include <cstdlib>
#include <cstring>

#define TASKNAME "primes"
enum {OK, WA, PE, JE, NUM};
const char err [NUM] [NUM] = {"OK", "WA", "PE", "JE"};
const int MinN = 1, MaxN = 10, Base = 10;
const int MaxBuf = 65536;

FILE * fin, * fout, * fans;

void chkexit (const char * msg, int code)
{
 fprintf (stdout, "%s: %s\n", err[code], msg);
 exit (code);
}

int n;

bool is_prime (long long k)
{
 long long i;
 if (k == 1) return false;
 if (k == 2) return true;
 if (!(k & 1)) return false;
 for (i = 3; i * i <= k; i += 2)
  if (!(k % i))
   return false;
 return true;
}

int answer (FILE * f, int mask)
{
 int a [MaxN];
 char buf [MaxBuf];
 int i, j, l, s;
 long long k;
 char ch;
 if (fgets (buf, sizeof (buf), f) == NULL)
  chkexit ("No answer given!", PE | mask);
 l = strlen (buf);
 if (buf[l - 1] == '\n')
 {
  buf[l - 1] = '0';
  l--;
 }
 if (l != n)
  chkexit ("String size is incorrect!", PE | mask);
 if (fscanf (f, " %c", &ch) != EOF)
  chkexit ("Extra info present!", PE | mask);

 for (i = 0; i < n; i++)
  a[i] = buf[i] - '0';

 s = 0;
 for (i = 0; i < n; i++)
  if (a[i] != 0)
  {
   k = 0;
   for (j = i; j < n; j++)
   {
    k = k * Base + a[j];
    s += is_prime (k);
   }
  }
 for (i = 0; i < n; i++)
  if (a[i] != 0)
  {
   k = 0;
   for (j = i; j >= 0; j--)
   {
    k = k * Base + a[j];
    s += is_prime (k);
   }
  }

 return s;
}

int main (int argc, char * argv [])
{
 int res1, res2;
 assert (argc >= 4);
 if ((fin = fopen (argv[1], "r")) == NULL) chkexit ("No input file!", JE);
 if ((fout = fopen (argv[2], "r")) == NULL) chkexit ("No output file!", PE);
 if ((fans = fopen (argv[3], "r")) == NULL) chkexit ("No answer file!", JE);

 fscanf (fin, " %d", &n);
 assert (n >= MinN && n <= MaxN);

 res1 = answer (fout, OK);
 res2 = answer (fans, JE);
 fprintf (stdout, "Jury: %d, Contestant: %d\n", res2, res1);
 chkexit ("Some answers were given.", OK);
 return 0;
}
